@@ -43,59 +43,8 @@
 #include <bits/std_istream.h>
 #include <bits/std_ostream.h>
 
-
 namespace std {
 
-  //
-  // string
-  //
-#if 0
-  template class basic_string<char>;
-#ifdef _G_USE_WCHAR_T
-  template class basic_string<wchar_t>;
-#endif
-#else
-  template 
-    string::basic_string(string::iterator, string::iterator, allocator<char> const&);
-
-  template 
-    wstring::basic_string(wstring::iterator, wstring::iterator, allocator<wchar_t> const&);
-
-  template 
-    char* 
-    string::_S_construct<char *>(char *, char *, allocator<char> const &, forward_iterator_tag);
-
-  template 
-    char* 
-    string::_S_construct<const char *>(const char *, const char *, allocator<char> const &, forward_iterator_tag);
-  
-  template wchar_t* wstring::_S_construct<wchar_t *>(wchar_t *, wchar_t *, allocator<wchar_t> const &, forward_iterator_tag);
-  
-  template wchar_t* wstring::_S_construct<const wchar_t *>(const wchar_t *, const wchar_t *, allocator<wchar_t> const &, forward_iterator_tag);
-
-  template 
-    string& 
-    string::_M_replace<char *>(string::iterator, string::iterator, char *, char *, forward_iterator_tag);
-  
- template string& string::_M_replace<const char *>(string::iterator, string::iterator, const char *, const char *, forward_iterator_tag);
-  
- template string& string::_M_replace<string::iterator>(string::iterator, string::iterator, string::iterator, string::iterator, forward_iterator_tag);
-  
- template string& string::_M_replace<string::const_iterator>(string::iterator, string::iterator, string::const_iterator, string::const_iterator, forward_iterator_tag);
- 
- template wstring& wstring::_M_replace<wchar_t *>(wstring::iterator, wstring::iterator, wchar_t *, wchar_t *, forward_iterator_tag);
- 
- template wstring& wstring::_M_replace<const wchar_t *>(wstring::iterator, wstring::iterator, const wchar_t *, const wchar_t *, forward_iterator_tag);
- 
- template wstring& wstring::_M_replace<wstring::iterator>(wstring::iterator, wstring::iterator, wstring::iterator, wstring::iterator, forward_iterator_tag);
- 
-    template wstring& wstring::_M_replace<wstring::const_iterator>(wstring::iterator, wstring::iterator, wstring::const_iterator, wstring::const_iterator, forward_iterator_tag);
-  
-  
-#endif
-
-
-
   //
   // streambuf
   // 
@@ -110,7 +59,7 @@ namespace std {
   //
   template class basic_stringbuf<char>;
 #ifdef _G_USE_WCHAR_T
-  //template class basic_stringbuf<wchar_t>;
+  template class basic_stringbuf<wchar_t>;
 #endif
 
 
@@ -145,8 +94,40 @@ namespace std {
   // ostream
   //
   template class basic_ostream<char>;
+  template ostream& endl(ostream&);
+  template ostream& ends(ostream&);
+  template ostream& flush(ostream&);
+  template ostream& operator<<(ostream&, const char*);
+  // template ostream& operator<<(ostream&, _Setfill<char>);
+  // template ostream& operator<<(ostream&, _Setw);
+  // template _Setfill<char> setfill(char);
 #ifdef _G_USE_WCHAR_T
-  template class basic_ostream<wchar_t>; 
+  template class basic_ostream<wchar_t>;
+  template wostream& endl(wostream&);
+  template wostream& ends(wostream&);
+  template wostream& flush(wostream&);
+  template wostream& operator<<(wostream&, const wchar_t*);
+  // template wostream& operator<<(wostream&, _Setfill<wchar_t>);
+  // template wostream& operator<<(wostream&, _Setw);
+  // template _Setfill<wchar_t> setfill(wchar_t);
+#endif
+  
+
+  //
+  // istringstream
+  //
+  template class basic_istringstream<char>;
+#ifdef _G_USE_WCHAR_T
+  template class basic_istringstream<wchar_t>; 
+#endif
+
+
+  //
+  // ostringstream
+  //
+  template class basic_ostringstream<char>;
+#ifdef _G_USE_WCHAR_T
+  template class basic_ostringstream<wchar_t>; 
 #endif
 
 
